@@ -3,8 +3,9 @@
 #define screen_h 1
 #include <std.h>
 #include <stdio.h>
+#ifndef __linux__
 #include <curses.h>
-
+#endif
 
 
 /* Handles necessary screen-manipultations. */
@@ -19,7 +20,6 @@ class Screen_Handler
   static char *inverse_end;        /* Control sequence ending inverse mode. */
   
   static void  center (char *buf); /* Prints out leading spaces to center BUF. */
-  static int   fputchar (int i);   /* Prints a character to standard output. */
 
 public:
               Screen_Handler (void);              /* Initialize the screen width. */
@@ -29,40 +29,10 @@ public:
 
 /* See comments in .cc file for inline functions. */
 
-#ifdef __OPTIMIZE__
+/* Returns current screen width. */
 inline int 
 Screen_Handler::screen_width (void)
 {
   return width;
 }
-
-inline int 
-Screen_Handler::fputchar (int i)
-{
-  putchar (i);
-}
-
-inline void 
-Screen_Handler::center (char *buf)
-{
-  int offset;
-  int len = strlen (buf);
-  
-  offset = width - len >> 1;
-  
-  for (int i = 0; i < offset; i++)
-    putchar (' ');
-}
-
-inline void 
-Screen_Handler::print_inverse_centered (char *buf)
-{
-  putchar ('\n');
-  center (buf);
-  tputs (inverse_start, 1, fputchar);
-  printf ("%s\n\n", buf);
-  tputs (inverse_end, 1, fputchar);
-}
-
-#endif // __OPTIMIZE__
 #endif
